import {
  select,
  geoPath, 
  geoNaturalEarth1, 
  zoom, 
  event,
  scaleOrdinal,
  schemeSpectral
} from 'd3';
import { loadAndProcessData } from './loadAndProcessData';
import { colorLegend } from './colorLegend';

const svg = select('svg');

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

const g = svg.append('g');

const colorLegendG = svg.append('g')
  .attr('transform', `translate(30, 300)`);

g.append('path')
    .attr('class', 'sphere')
    .attr('d', pathGenerator({type: 'Sphere'}));

svg.call(zoom().on('zoom', () => {
  g.attr('transform', event.transform);
}));

const colorScale = scaleOrdinal();	// apply 10 prechosen colors(schemeCategory10)

const colorValue = d => d.properties.income_grp;  // d.properties.economy

loadAndProcessData().then(countries => {  // load and process data in another module & you can just focus on visualization in here
  
  colorScale
    .domain(countries.features.map(colorValue))  // set the domain to economy values (this removes duplicates: turns to unique vals)
    .domain(colorScale.domain().sort().reverse())
    .range(schemeSpectral[colorScale.domain().length]);  //  set the domain again to sort the uniqued domain array
  
  colorLegendG.call(colorLegend, {
    colorScale,
    circleRadius: 8,
    spacing: 20,
    textOffset: 10,
    backgroundRectWidth: 235
  });
  
  g.selectAll('path').data(countries.features)
    .enter().append('path')
      .attr('class', 'country')
      .attr('d', pathGenerator)
      .attr('fill', d => colorScale(colorValue(d)))
    .append('title')	// for svg, need to append 'title' tags as children elements to the path elements
      .text(d => d.properties.name + ': ' + colorValue(d));	// show tooltip on hover
});